..
    Copyright (c) 2018..2020 Bobby Noelte
    SPDX-License-Identifier: Apache-2.0

.. _cogeno_modules_cmake:

CMake support functions
########################

The CMake module provides access to CMake variables and the CMake cache.

You may get access to the database by :func:`cogeno.stdmodules.StdModulesMixin.cmake()`.

There are convenience functions to access the CMake variables:

*  :func:`cogeno.cmake_variable()`
*  :func:`cogeno.cmake_cache_variable()`


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   cmake_api

